# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .vellum_audio import VellumAudio


class TestCaseAudioVariableValue(UniversalBaseModel):
    """
    An audio value for a variable in a Test Case.
    """

    variable_id: str
    name: typing.Optional[str] = None
    type: typing.Literal["AUDIO"] = "AUDIO"
    value: typing.Optional[VellumAudio] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
